summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/ksliderwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/ksliderwindow.h')
-rw-r--r--kmplot/kmplot/ksliderwindow.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kmplot/kmplot/ksliderwindow.h b/kmplot/kmplot/ksliderwindow.h
index ff4843c8..79a3f089 100644
--- a/kmplot/kmplot/ksliderwindow.h
+++ b/kmplot/kmplot/ksliderwindow.h
@@ -34,10 +34,11 @@
class KSliderWindow : public SliderWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
/// @param parent points to the parent widget.
/// @param num number of this instance.
- KSliderWindow(TQWidget* parent, int num );
+ KSliderWindow(TQWidget* tqparent, int num );
virtual ~KSliderWindow();
private slots:
@@ -34,10 +34,11 @@
public:
- /// @param parent points to the parent widget.
+ /// @param tqparent points to the tqparent widget.
/// @param num number of this instance.